pub struct KeyedWorkerPoolConfig {
pub max_count: Option<u16>,
pub idle_timeout: Option<Duration>,
pub max_count_per_key: Option<u16>,
}Fields
max_count: Option<u16>Target maximum number of workers managed by the pool.
None leaves the worker count unlimited. A finite target may be
temporarily exceeded to create a worker for a missing key.
idle_timeout: Option<Duration>max_count_per_key: Option<u16>Maximum number of workers whose primary key is the same.
None leaves key counts unlimited. This limit is independent
of the pool-wide max_count target.