pub trait WorkerFactory<W: Worker>:
Send
+ Sync
+ 'static {
// Required method
fn create<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = PoolResult<W>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn create<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = PoolResult<W>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = PoolResult<W>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates a usable worker.
Returning Ok asserts that the worker is ready for use. The pool does not
call Worker::is_work before handing a newly created worker to the caller.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".